@@ -42,7 +42,7 @@ class DefaultClient:
         if not isinstance(self._server, (list, tuple, set)):
             self._server = self._server.split(",")
 
-        self._clients = [None] * len(self._server)  # type: List[Optional[Redis]]
+        self._clients: List[Optional[Redis]] = [None] * len(self._server)
         self._options = params.get("OPTIONS", {})
         self._replica_read_only = self._options.get("REPLICA_READ_ONLY", True)
 
@@ -146,7 +146,7 @@ class DefaultClient:
             timeout = self._backend.default_timeout
 
         original_client = client
-        tried = []  # type: List[int]
+        tried: List[int] = []
         while True:
             try:
                 if client is None:
@@ -266,14 +266,13 @@ class DefaultClient:
 
     def persist(
         self, key: Any, version: Optional[int] = None, client: Optional[Redis] = None
-    ) -> None:
+    ) -> bool:
         if client is None:
             client = self.get_client(write=True)
 
         key = self.make_key(key, version=version)
 
-        if client.exists(key):
-            client.persist(key)
+        return client.persist(key)
 
     def expire(
         self,
@@ -281,31 +280,31 @@ class DefaultClient:
         timeout,
         version: Optional[int] = None,
         client: Optional[Redis] = None,
-    ) -> None:
+    ) -> bool:
         if client is None:
             client = self.get_client(write=True)
 
         key = self.make_key(key, version=version)
 
-        if client.exists(key):
-            client.expire(key, timeout)
+        return client.expire(key, timeout)
 
-    def pexpire(self, key, timeout, version=None, client=None):
+    def pexpire(self, key, timeout, version=None, client=None) -> bool:
         if client is None:
             client = self.get_client(write=True)
 
         key = self.make_key(key, version=version)
 
-        if client.exists(key):
-            client.pexpire(key, timeout)
+        # Temporary casting until https://github.com/redis/redis-py/issues/1664
+        # is fixed.
+        return bool(client.pexpire(key, timeout))
 
-    def expire_at(
+    def pexpire_at(
         self,
         key: Any,
         when: Union[datetime, int],
         version: Optional[int] = None,
         client: Optional[Redis] = None,
-    ) -> None:
+    ) -> bool:
         """
         Set an expire flag on a ``key`` to ``when``, which can be represented
         as an integer indicating unix time or a Python datetime object.
@@ -315,8 +314,25 @@ class DefaultClient:
 
         key = self.make_key(key, version=version)
 
-        if client.exists(key):
-            client.expireat(key, when)
+        return bool(client.pexpireat(key, when))
+
+    def expire_at(
+        self,
+        key: Any,
+        when: Union[datetime, int],
+        version: Optional[int] = None,
+        client: Optional[Redis] = None,
+    ) -> bool:
+        """
+        Set an expire flag on a ``key`` to ``when``, which can be represented
+        as an integer indicating unix time or a Python datetime object.
+        """
+        if client is None:
+            client = self.get_client(write=True)
+
+        key = self.make_key(key, version=version)
+
+        return client.expireat(key, when)
 
     def lock(
         self,
