@@ -41,7 +41,7 @@ class HerdClient(DefaultClient):
 
     def _pack(self, value, timeout):
         herd_timeout = (timeout or self._backend.default_timeout) + int(time.time())
-        return (self._marker, value, herd_timeout)
+        return self._marker, value, herd_timeout
 
     def _unpack(self, value):
         try:
