@@ -17,7 +17,7 @@ class ConnectionFactory:
     # ConnectionFactory is instantiated, as Django creates new cache client
     # (DefaultClient) instance for every request.
 
-    _pools = {}  # type: Dict[str, Redis]
+    _pools: Dict[str, Redis] = {}
 
     def __init__(self, options):
         pool_cls_path = options.get(
