@@ -1,4 +1,5 @@
 import json
+from typing import Any
 
 from django.core.serializers.json import DjangoJSONEncoder
 
@@ -8,8 +9,8 @@ from .base import BaseSerializer
 class JSONSerializer(BaseSerializer):
     encoder_class = DjangoJSONEncoder
 
-    def dumps(self, value):
+    def dumps(self, value: Any) -> bytes:
         return json.dumps(value, cls=self.encoder_class).encode()
 
-    def loads(self, value):
+    def loads(self, value: bytes) -> Any:
         return json.loads(value.decode())
